package com.risk.app.config;

import androidx.multidex.MultiDex;
import androidx.multidex.MultiDexApplication;

import com.blankj.utilcode.util.Utils;
import com.elvishew.xlog.LogConfiguration;
import com.elvishew.xlog.XLog;
import com.elvishew.xlog.flattener.ClassicFlattener;
import com.elvishew.xlog.printer.Printer;
import com.elvishew.xlog.printer.file.FilePrinter;
import com.elvishew.xlog.printer.file.backup.BackupStrategy2;
import com.elvishew.xlog.printer.file.backup.FileSizeBackupStrategy2;
import com.elvishew.xlog.printer.file.clean.FileLastModifiedCleanStrategy;
import com.elvishew.xlog.printer.file.naming.ChangelessFileNameGenerator;


public class App extends MultiDexApplication {

    private static App instance;

    public static App getInstance() {
        return instance;
    }

    @Override
    public void onCreate() {
        super.onCreate();
        instance = this;
        MultiDex.install(this);
        Printer filePrinter = new FilePrinter
                .Builder(Utils.getApp().getFilesDir().getPath() + "/ulog")
                .fileNameGenerator(new ChangelessFileNameGenerator( "risk_log.txt"))
                .backupStrategy(new FileSizeBackupStrategy2(1024 * 1024 * 5, BackupStrategy2.NO_LIMIT))
                .cleanStrategy(new FileLastModifiedCleanStrategy(1000 * 60 * 24 * 7))
                .flattener(new ClassicFlattener())
                .build();
        LogConfiguration config = new LogConfiguration.Builder()
                .tag("risk_test_tag").build();
        XLog.init(config, filePrinter);
    }


}
